==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "დავალებები",
    "Due yesterday" : "გუშინდელი დღისთვის",
    "Due today" : "დღეისთვის",
    "Due tomorrow" : "ხვალისთვის",
    "Due on" : "განპირობებული",
    "Started yesterday" : "დაიწყო გუში",
    "Starts today" : "იწყება დღეს",
    "Starts tomorrow" : "იწყება ხვალ",
    "Started on" : "დაიწყო",
    "Starts on" : "იწყება",
    "[Remind me yesterday at ]HH:mm" : "[გამახსენეთ გუშინ ]HH:mm",
    "[Remind me today at ]HH:mm" : "[გამახსენეთ დღეს ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[გამახსენეთ ხვალ ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[გამახსენეთ ]MMM DD, YYYY,[ at ]HH:mm",
    "Yesterday" : "გუშინ",
    "Today" : "დღეს",
    "Tomorrow" : "ხვალ",
    "in %s" : "%s-ში",
    "%s ago" : "%s-ის წინ",
    "seconds" : "წამი",
    "a minute" : "წუთი",
    "%d minutes" : "%d წუთი",
    "an hour" : "საათი",
    "%d hours" : "%d საათი",
    "a day" : "დღე",
    "%d days" : "%d დღე",
    "a month" : "თვე",
    "%d months" : "%d თვე",
    "a year" : "წელი",
    "%d years" : "%d წელი",
    "week" : "კვირა",
    "weeks" : "კვირა",
    "day" : "დღე",
    "days" : "დღე",
    "hour" : "საათი",
    "hours" : "საათი",
    "minute" : "წუთი",
    "minutes" : "წუთი",
    "second" : "წამი",
    "before beginning" : "დაწყებამდე",
    "after beginning" : "დაწყების შემდეგ",
    "before end" : "დასრულებამდე",
    "after end" : "დასრულების შემდეგ",
    "Comment" : "კომენტარი",
    "Add a comment" : "კომენტარის დამატება",
    "This will delete the Calendar \"%s\" and all of its entries." : "ეს გააუქმებს კალენდარს \"%s\" და მის ჩანაწერებს.",
    "The name \"%s\" is already used." : "სახელი \"%s\" უკვე დაკავებულია",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Add an important item in \"%s\"..." : "მნიშვნელოვანი ელემენტის დამატება \"%s\"-ში…",
    "Add an item due today in \"%s\"..." : "ელემენტის \"%s\" დამატება დღეისთვის…",
    "Add an item in \"%s\"..." : "ელემენტის დამატება \"%s\"-ში…",
    "Add a current item in \"%s\"..." : "ამჟამინდელი ელემენტის დამატება \"%s\"-ში…",
    "Add a subtask to \"%s\"..." : "ქვე-დავალების დამატება \"%s\"-ში…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება"],
    "Hours" : "საათი",
    "Minutes" : "წუთი",
    "Set due date" : "განპირობებულია თარიღისთვის",
    "%s %% completed" : "%s %% დასრულდა",
    "priority %s: " : "პრიორიტეტი %s: ",
    "high" : "მაღალი",
    "medium" : "საშუალო",
    "low" : "დაბალი",
    "no priority assigned" : "პრიორიტეტი მინიჭებული არაა",
    "Remind me" : "შემახსენეთ",
    "at the end" : "ბოლოს",
    "at the beginning" : "დასაწყისში",
    "Set start date" : "საწყისი დრო",
    "{calendar} shared by {owner}" : "{calendar} გააზიარა მფლობელმა {owner}",
    "Unnamed" : "უსახელო",
    "Important" : "აუცილებელი",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Delete" : "წაშლა",
    "Cancel" : "უარყოფა",
    "Edit" : "რედაქტირება",
    "Link" : "ბმული",
    "Download" : "ჩამოტვირთვა",
    "Save" : "შენახვა",
    "Add List..." : "სიის დამატება…",
    "New List" : "ახალი სია",
    "Settings" : "პარამეტრები",
    "Start of week" : "კვირის დასაწყისი",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Change sort order" : "განლაგების შეცვლა",
    "Default" : "საწყისი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Start date" : "დაწყების თარიღი",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Manually" : "ხელით",
    "Load remaining completed tasks." : "დარჩენილი დასრულებული დავალებების ჩატვირთვა.",
    "Task is completed" : "დავალება დასრულებულია",
    "All day" : "მთელი დღე",
    "(New category)" : "(ახალი კატეგორია)",
    "Select categories..." : "კატეგორიების არჩევა…",
    "Loading the task..." : "დავალების ჩატვირთვა…",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "add a subtask to" : "დაუმატეთ ქვედავალება",
    "Toggle subtasks" : "ქვე-დავალებების გადართვა",
    "Toggle completed subtasks" : "დასრულებული ქვე-დავალებების გადართვა"
},
"nplurals=1; plural=0;");

==> nextcloud-app-tasks-0.9.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "დავალებები",
    "Due yesterday" : "გუშინდელი დღისთვის",
    "Due today" : "დღეისთვის",
    "Due tomorrow" : "ხვალისთვის",
    "Due on" : "განპირობებული",
    "Started yesterday" : "დაიწყო გუში",
    "Starts today" : "იწყება დღეს",
    "Starts tomorrow" : "იწყება ხვალ",
    "Started on" : "დაიწყო",
    "Starts on" : "იწყება",
    "[Remind me yesterday at ]HH:mm" : "[გამახსენეთ გუშინ ]HH:mm",
    "[Remind me today at ]HH:mm" : "[გამახსენეთ დღეს ]HH:mm",
    "[Remind me tomorrow at ]HH:mm" : "[გამახსენეთ ხვალ ]HH:mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[გამახსენეთ ]MMM DD, YYYY,[ at ]HH:mm",
    "Yesterday" : "გუშინ",
    "Today" : "დღეს",
    "Tomorrow" : "ხვალ",
    "in %s" : "%s-ში",
    "%s ago" : "%s-ის წინ",
    "seconds" : "წამი",
    "a minute" : "წუთი",
    "%d minutes" : "%d წუთი",
    "an hour" : "საათი",
    "%d hours" : "%d საათი",
    "a day" : "დღე",
    "%d days" : "%d დღე",
    "a month" : "თვე",
    "%d months" : "%d თვე",
    "a year" : "წელი",
    "%d years" : "%d წელი",
    "week" : "კვირა",
    "weeks" : "კვირა",
    "day" : "დღე",
    "days" : "დღე",
    "hour" : "საათი",
    "hours" : "საათი",
    "minute" : "წუთი",
    "minutes" : "წუთი",
    "second" : "წამი",
    "before beginning" : "დაწყებამდე",
    "after beginning" : "დაწყების შემდეგ",
    "before end" : "დასრულებამდე",
    "after end" : "დასრულების შემდეგ",
    "Comment" : "კომენტარი",
    "Add a comment" : "კომენტარის დამატება",
    "This will delete the Calendar \"%s\" and all of its entries." : "ეს გააუქმებს კალენდარს \"%s\" და მის ჩანაწერებს.",
    "The name \"%s\" is already used." : "სახელი \"%s\" უკვე დაკავებულია",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Sunday" : "კვირა",
    "Monday" : "ორშაბათი",
    "Tuesday" : "სამშაბათი",
    "Wednesday" : "ოთხშაბათი",
    "Thursday" : "ხუთშაბათი",
    "Friday" : "პარასკევი",
    "Saturday" : "შაბათი",
    "Add an important item in \"%s\"..." : "მნიშვნელოვანი ელემენტის დამატება \"%s\"-ში…",
    "Add an item due today in \"%s\"..." : "ელემენტის \"%s\" დამატება დღეისთვის…",
    "Add an item in \"%s\"..." : "ელემენტის დამატება \"%s\"-ში…",
    "Add a current item in \"%s\"..." : "ამჟამინდელი ელემენტის დამატება \"%s\"-ში…",
    "Add a subtask to \"%s\"..." : "ქვე-დავალების დამატება \"%s\"-ში…",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
    "Hours" : "საათი",
    "Minutes" : "წუთი",
    "Set due date" : "განპირობებულია თარიღისთვის",
    "%s %% completed" : "%s %% დასრულდა",
    "priority %s: " : "პრიორიტეტი %s: ",
    "high" : "მაღალი",
    "medium" : "საშუალო",
    "low" : "დაბალი",
    "no priority assigned" : "პრიორიტეტი მინიჭებული არაა",
    "Remind me" : "შემახსენეთ",
    "at the end" : "ბოლოს",
    "at the beginning" : "დასაწყისში",
    "Set start date" : "საწყისი დრო",
    "{calendar} shared by {owner}" : "{calendar} გააზიარა მფლობელმა {owner}",
    "Unnamed" : "უსახელო",
    "Important" : "აუცილებელი",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Delete" : "წაშლა",
    "Cancel" : "უარყოფა",
    "Edit" : "რედაქტირება",
    "Link" : "ბმული",
    "Download" : "ჩამოტვირთვა",
    "Save" : "შენახვა",
    "Add List..." : "სიის დამატება…",
    "New List" : "ახალი სია",
    "Settings" : "პარამეტრები",
    "Start of week" : "კვირის დასაწყისი",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Change sort order" : "განლაგების შეცვლა",
    "Default" : "საწყისი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Start date" : "დაწყების თარიღი",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Manually" : "ხელით",
    "Load remaining completed tasks." : "დარჩენილი დასრულებული დავალებების ჩატვირთვა.",
    "Task is completed" : "დავალება დასრულებულია",
    "All day" : "მთელი დღე",
    "(New category)" : "(ახალი კატეგორია)",
    "Select categories..." : "კატეგორიების არჩევა…",
    "Loading the task..." : "დავალების ჩატვირთვა…",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "add a subtask to" : "დაუმატეთ ქვედავალება",
    "Toggle subtasks" : "ქვე-დავალებების გადართვა",
    "Toggle completed subtasks" : "დასრულებული ქვე-დავალებების გადართვა"
},
"nplurals=2; plural=(n!=1);");
